@@ -37,7 +37,7 @@ class AIS:
         "retry_error_callback": error_callback
     }
     def __init__(self, proxy=False, verbose=False, columns="all", columns_excluded=None, print_query = False,
-                 num_retries=10, seconds_wait=15, filter_config=None, return_df=False, return_total_count=False,
+                 num_retries=10, seconds_wait=15, filter_config={}, return_df=False, return_total_count=False,
                  **proxy_config):
         # Setting Retry Options
         if num_retries != 10:
